# Copyright 2017 Red Hat, Inc
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
# implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import json
import os

from os_service_types import types

__all__ = ['read_data']

DATA_DIR = os.path.dirname(__file__)


def read_data(filename: str) -> types.ServiceTypes:
    """Return data that is shipped inside the Python package."""

    filepath = os.path.join(DATA_DIR, filename)
    with open(filepath) as fd:
        data: types.ServiceTypes = json.load(fd)

    return data
